@@ -1410,6 +1410,54 @@ def get_overdue_amount(robo_idt_view):
 # nguyenhuuvinh4 START
 
 
+def get_registration_and_act_hi_var_from_dwh(appId):
+    SQL = "SELECT * DWROBOWLBL.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID = '{}' OR s.EX_APPLICATION_ID = '{}'"
+    SQL = SQL.format(appId, appId)
+    print(SQL)
+    connection = cx_Oracle.connect(
+        "PATTA_RAJESH", "Pa55w0rd_$U", "172.27.1.7:1521/dwproddc", encoding="utf-8", nencoding="UTF-8")
+    cursorRegis = connection.cursor()
+    cursorRegis.execute(SQL)
+    response = []
+    responseRegis = []
+    isWhitelabel = False
+    if not cursorRegis:
+        isWhitelabel = True
+        for row in cursorRegis:
+            responseRegis.append(row)
+    else:
+        SQL = "SELECT * DWROBOLENDING.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID = '{}'"
+        SQL = SQL.format(appId)
+        print(SQL)
+        cursorRegis = connection.cursor()
+        cursorRegis.execute(SQL)
+        for row in cursorRegis:
+            responseRegis.append(row)
+    cursorRegis.close()
+
+    responseVar = [] 
+    if isWhitelabel:
+        SQL = "SELECT * FROM DWROBOWLBL.ACT_HI_VARINST as r WHERE r.PROC_INST_ID_  = '{}'"
+        SQL = SQL.format(appId)
+        print(SQL)
+        cursorVar = connection.cursor()
+        cursorVar.execute(SQL)
+        for row in cursorVar:
+            responseVar.append(row)
+    else:
+        SQL = "SELECT * FROM DWROBOLENDING.ACT_HI_VARINST as r WHERE r.PROC_INST_ID_  = '{}'"
+        SQL = SQL.format(appId)
+        print(SQL)
+        cursorVar = connection.cursor()
+        cursorVar.execute(SQL)
+        for row in cursorVar:
+            responseVar.append(row)
+    response.append(responseRegis)
+    response.append(responseVar)
+    connection.close()
+    return response
+
+
 def get_data_from_cust_con_add(contract_number):
     SQL = "SELECT s.CONTRACT_NO,s.FULL_ADDRESS,s.CCDM_CUST_ID,s.CUST_NAME,s.TYPE_OF_NO,s.UNQ_ID,s.DISBURSAL_DT FROM ccdm.CUST_CON_ADD s WHERE s.CONTRACT_NO = '{}'"
     SQL = SQL.format(contract_number)
